@@ -1,7 +1,7 @@
 // samplv1_config.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2023, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2024, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -42,7 +42,7 @@ samplv1_config *samplv1_config::getInstance (void)
 
 // Constructor.
 samplv1_config::samplv1_config (void)
-	: QSettings(SAMPLV1_DOMAIN, SAMPLV1_TITLE)
+	: QSettings(PROJECT_DOMAIN, PROJECT_NAME)
 {
 	g_pSettings = this;
 
@@ -353,7 +353,7 @@ void samplv1_config::load (void)
 void samplv1_config::save (void)
 {
 	QSettings::beginGroup("/Program");
-	QSettings::setValue("/Version", CONFIG_BUILD_VERSION);
+	QSettings::setValue("/Version", PROJECT_VERSION);
 	QSettings::endGroup();
 
 	QSettings::beginGroup("/Default");
