@@ -1,7 +1,7 @@
 // samplv1_sample.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2023, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2024, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -45,6 +45,21 @@ samplv1_sample::samplv1_sample ( float srate )
 }
 
 
+// copy-ctor.
+samplv1_sample::samplv1_sample ( const samplv1_sample& sample )
+	: samplv1_sample(sample.m_srate)
+{
+	m_loop    = sample.m_loop;
+	m_offset  = sample.m_offset;
+	m_reverse = sample.m_reverse;
+
+	m_loop_xfade = sample.m_loop_xfade;
+	m_loop_xzero = sample.m_loop_xzero;
+
+	m_loop_end_release = sample.m_loop_end_release;
+}
+
+
 // dtor.
 samplv1_sample::~samplv1_sample (void)
 {
