@@ -1,7 +1,7 @@
 // samplv1_ui.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2024, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2025, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -217,6 +217,12 @@ void samplv1_ui::updatePreset ( bool bDirty )
 }
 
 
+void samplv1_ui::updateParam ( samplv1::ParamIndex index )
+{
+	m_pSampl->updateParam(index);
+}
+
+
 void samplv1_ui::midiInEnabled ( bool bEnabled )
 {
 	m_pSampl->midiInEnabled(bEnabled);
