@@ -1,7 +1,7 @@
 // samplv1widget_controls.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2022, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2023, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -39,7 +39,7 @@ class samplv1widget_controls::ItemDelegate : public QItemDelegate
 public:
 
 	// ctor.
-	ItemDelegate(QObject *pParent = 0);
+	ItemDelegate(QObject *pParent = nullptr);
 
 	// QItemDelegate interface...
 	QSize sizeHint(
