@@ -23,6 +23,7 @@
 #define __samplv1widget_env_h
 
 #include <QFrame>
+#include <QPolygon>
 
 
 //----------------------------------------------------------------------------
@@ -66,6 +67,16 @@ protected:
 	// Draw canvas.
 	void paintEvent(QPaintEvent *);
 
+	// Parameter node indexes.
+	enum NodeIndex {
+		Idle    = 1,
+		Attack  = 2,
+		Decay   = 3,
+		Sustain = 4,
+		Release = 5,
+		End     = 6
+	};
+
 	// Draw rectangular point.
 	QRect nodeRect(int iNode) const;
 	int nodeIndex(const QPoint& pos) const;
@@ -77,6 +88,12 @@ protected:
 	void mouseMoveEvent(QMouseEvent *pMouseEvent);
 	void mouseReleaseEvent(QMouseEvent *pMouseEvent);
 
+	// Resize canvas.
+	void resizeEvent(QResizeEvent *);
+
+	// Update the drawing polygon.
+	void updatePolygon();
+
 private:
 
 	// Instance state.
