@@ -1,7 +1,7 @@
 // samplv1widget_lv2.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2024, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2025, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -209,6 +209,15 @@ void samplv1widget_lv2::port_event ( uint32_t port_index,
 void samplv1widget_lv2::updateParam (
 	samplv1::ParamIndex index, float fValue ) const
 {
+	if (index == samplv1::GEN1_OFFSET_1 ||
+		index == samplv1::GEN1_OFFSET_2 ||
+		index == samplv1::GEN1_LOOP_1   ||
+		index == samplv1::GEN1_LOOP_2) {
+		m_pSamplUi->setParamValue(index, fValue);
+		m_pSamplUi->updateParam(index);
+		return;
+	}
+
 	m_pSamplUi->write_function(index, fValue);
 }
 
